summaryrefslogtreecommitdiff
path: root/src/script/api/script_cargolist.hpp
diff options
context:
space:
mode:
authortruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
committertruebrain <truebrain@openttd.org>2011-11-29 23:15:35 +0000
commit98103121d4f2ed1f1581919b7b1f343ccd410c12 (patch)
tree1e760dd6517a6b0f9fb669ec277139a8e3f9a4a3 /src/script/api/script_cargolist.hpp
parentafdb67a3534f85b4efbd3327ece8137211042d7b (diff)
downloadopenttd-98103121d4f2ed1f1581919b7b1f343ccd410c12.tar.xz
(svn r23355) -Codechange: rename all AI* to Script* (Rubidium)
Diffstat (limited to 'src/script/api/script_cargolist.hpp')
-rw-r--r--src/script/api/script_cargolist.hpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/script/api/script_cargolist.hpp b/src/script/api/script_cargolist.hpp
index 334792358..964d46fca 100644
--- a/src/script/api/script_cargolist.hpp
+++ b/src/script/api/script_cargolist.hpp
@@ -16,49 +16,49 @@
/**
* Creates a list of cargos that can be produced in the current game.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AICargoList : public AIList {
+class ScriptCargoList : public ScriptList {
public:
- AICargoList();
+ ScriptCargoList();
};
/**
* Creates a list of cargos that the given industry accepts.
* @note This list also includes cargos that are temporarily not accepted
* by this industry, @see AIIndustry::IsCargoAccepted.
* @ingroup AIList
*/
-class AICargoList_IndustryAccepting : public AIList {
+class ScriptCargoList_IndustryAccepting : public ScriptList {
public:
/**
* @param industry_id The industry to get the list of cargos it accepts from.
*/
- AICargoList_IndustryAccepting(IndustryID industry_id);
+ ScriptCargoList_IndustryAccepting(IndustryID industry_id);
};
/**
* Creates a list of cargos that the given industry can produce.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AICargoList_IndustryProducing : public AIList {
+class ScriptCargoList_IndustryProducing : public ScriptList {
public:
/**
* @param industry_id The industry to get the list of cargos it produces from.
*/
- AICargoList_IndustryProducing(IndustryID industry_id);
+ ScriptCargoList_IndustryProducing(IndustryID industry_id);
};
/**
* Creates a list of cargos that the given station accepts.
- * @ingroup AIList
+ * @ingroup ScriptList
*/
-class AICargoList_StationAccepting : public AIList {
+class ScriptCargoList_StationAccepting : public ScriptList {
public:
/**
* @param station_id The station to get the list of cargos it accepts from.
*/
- AICargoList_StationAccepting(StationID station_id);
+ ScriptCargoList_StationAccepting(StationID station_id);
};
#endif /* SCRIPT_CARGOLIST_HPP */
@@ -16,49 +16,49 @@
* Creates a list of cargos that the given industry accepts.
* @note This list also includes cargos that are temporarily not accepted
- * by this industry, @see AIIndustry::IsCargoAccepted.
- * @ingroup AIList
+ * by this industry, @see ScriptIndustry::IsCargoAccepted.
+ * @ingroup ScriptList
*/